@@ -16,10 +16,14 @@
 # along with Cloud Builder.  If not, see <http://www.gnu.org/licenses/>
 #
 import yaml
+from typing import (
+    Any, Dict
+)
 from cloud_builder.logger import CBLogger
 from cloud_builder.defaults import Defaults
 from cloud_builder.identity import CBIdentity
-from typing import Dict
+from cloud_builder.response.response import CBResponse
+from cloud_builder.info_response.info_response import CBInfoResponse
 
 
 class CBCloudLogger:
@@ -49,7 +53,7 @@ class CBCloudLogger:
 
     def info(self, message: str) -> None:
         """
-        Local log for info message
+        Local log an info message
 
         :param str message: message
         """
@@ -57,7 +61,7 @@ class CBCloudLogger:
 
     def warning(self, message: str) -> None:
         """
-        Local log for warning message
+        Local log a warning message
 
         :param str message: message
         """
@@ -65,20 +69,54 @@ class CBCloudLogger:
 
     def error(self, message: str) -> None:
         """
-        Local log for error message
+        Local log an error message
 
         :param str message: message
         """
         self.log.error(f'{self.id}: {message}')
 
-    def response(self, message: Dict) -> None:
+    def info_response(
+        self, response: CBInfoResponse, broker: Any, filename: str = None
+    ) -> None:
         """
-        Message broker plus local info log for
-        response message
+        Local and message broker log a CBInfoResponse message
 
-        :param dict message: yaml dict message
+        :param CBInfoResponse response: instance of CBInfoResponse
+        :param CBMessageBroker broker: instance of CBMessageBroker
+        :param str filename: store to filename in yaml format
+        """
+        self._process_response(response.get_data(), filename)
+        broker.send_info_response(response)
+
+    def response(
+        self, response: CBResponse, broker: Any, filename: str = None
+    ) -> None:
+        """
+        Local and message broker log a CBResponse message
+
+        :param CBResponse response: instance of CBResponse
+        :param CBMessageBroker broker: instance of CBMessageBroker
+        :param str filename: store to filename in yaml format
+        """
+        self._process_response(response.get_data(), filename)
+        broker.send_response(response)
+
+    def _process_response(
+        self, response_dict: Dict, filename: str = None
+    ) -> None:
+        """
+        Local log a response_dict
+
+        :param Dict response_dict: message dict
+        :param str filename: store to filename in yaml format
         """
         self.log.info(
-            '{0}: {1}'.format(self.id, yaml.dump(message).encode())
+            '{0}: {1}'.format(
+                self.id, yaml.dump(response_dict).encode()
+            )
         )
-        # TODO: send this information to Defaults.get_response_queue_name()
+        if filename:
+            with open(filename, 'w') as out:
+                yaml.dump(
+                    response_dict, out, default_flow_style=False
+                )
